==> qtkeychain_0.1.0-3.tar.gz: qtkeychain-0.1.0/translations/qtkeychain_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ro_RO">
<context>
    <name>QKeychain::ReadPasswordJobPrivate</name>
    <message>
        <location filename="../keychain_dbus.cpp" line="176"/>
        <source>Unknown error</source>
        <translation>Eroare necunoscută</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="190"/>
        <source>D-Bus is not running</source>
        <translation>D-Bus nu rulează</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="267"/>
        <source>No keychain service available</source>
        <translatorcomment>Nu există niciun serviciu de chei disponibil</translatorcomment>
        <translation>Kein Schlüsselbund-Dienst verfügbar</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="269"/>
        <source>Could not open wallet: %1; %2</source>
        <translation>Nu se poate deschide portofelul: %1; %2</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="315"/>
        <source>Access to keychain denied</source>
        <translation>Acces interzis la serviciul de chei</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="336"/>
        <source>Could not determine data type: %1; %2</source>
        <translation>Nu se poate stabili tipul de date: %1: %2</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="354"/>
        <source>Unsupported entry type &apos;Map&apos;</source>
        <translation>Tip de înregistrare nesuportat &apos;Map&apos;</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="357"/>
        <source>Unknown kwallet entry type &apos;%1&apos;</source>
        <translation>Tip de înregistrare kwallet necunoscut &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="372"/>
        <source>Could not read password: %1; %2</source>
        <translation>Nu se poate citi parola: %1; %2</translation>
    </message>
    <message>
        <location filename="../keychain_mac.cpp" line="76"/>
        <source>Password not found</source>
        <translation>Parola nu a fost găsită</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="345"/>
        <location filename="../keychain_win.cpp" line="27"/>
        <source>Entry not found</source>
        <translation>Înregistrarea nu a fost găsită</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="44"/>
        <source>Could not decrypt data</source>
        <translation>Nu se poate decripta data</translation>
    </message>
</context>
<context>
    <name>QKeychain::WritePasswordJobPrivate</name>
    <message>
        <location filename="../keychain_dbus.cpp" line="393"/>
        <location filename="../keychain_dbus.cpp" line="401"/>
        <source>Unknown error</source>
        <translation>Eroare necunoscută</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="416"/>
        <source>D-Bus is not running</source>
        <translation>D-Bus nu rulează</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="457"/>
        <location filename="../keychain_dbus.cpp" line="533"/>
        <source>Could not open wallet: %1; %2</source>
        <translation>Nu se poate deschide portofelul: %1; %2</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="511"/>
        <source>Access to keychain denied</source>
        <translation>Acces interzis la serviciul de chei</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="64"/>
        <source>Could not delete encrypted data from settings: access error</source>
        <translation>Nu se pot șterge datele criptate din setări: eroare de acces</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="65"/>
        <source>Could not delete encrypted data from settings: format error</source>
        <translation>Nu se pot șterge datele criptate din setări: eroare de format</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="85"/>
        <source>Encryption failed</source>
        <translation>Criptarea a eșuat</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="100"/>
        <source>Could not store encrypted data in settings: access error</source>
        <translation>Nu se pot stoca datele criptate în setări: eroare de acces</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="101"/>
        <source>Could not store encrypted data in settings: format error</source>
        <translation>Nu se pot stoca datele criptate în setări: eroare de format</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../keychain_dbus.cpp" line="212"/>
        <source>Access to keychain denied</source>
        <translation>Acces interzis la serviciul de chei</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="214"/>
        <source>No keyring daemon</source>
        <translation>Niciun demon pentru inelul de chei</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="216"/>
        <source>Already unlocked</source>
        <translation>Deja deblocat</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="218"/>
        <source>No such keyring</source>
        <translation>Nu există astfel de inel de chei</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="220"/>
        <source>Bad arguments</source>
        <translation>Argumente greșite</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="222"/>
        <source>I/O error</source>
        <translation>Eroare de I/E</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="224"/>
        <source>Cancelled</source>
        <translation>Anulat</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="226"/>
        <source>Keyring already exists</source>
        <translation>Inelul de chei deja există</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="228"/>
        <source>No match</source>
        <translation>Nicio potrivire</translation>
    </message>
    <message>
        <location filename="../keychain_dbus.cpp" line="233"/>
        <source>Unknown error</source>
        <translation>Eroare necunoscută</translation>
    </message>
    <message>
        <location filename="../keychain_mac.cpp" line="31"/>
        <location filename="../keychain_mac.cpp" line="33"/>
        <source>%1 (OSStatus %2)</source>
        <translation>%1 (OSStatus %2)</translation>
    </message>
</context>
</TS>

==> qtkeychain_0.3.0.orig.tar.gz: qtkeychain-0.3.0/translations/qtkeychain_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ro_RO">
<context>
    <name>QKeychain::ReadPasswordJobPrivate</name>
    <message>
        <location filename="../keychain_unix.cpp" line="53"/>
        <source>Unknown error</source>
        <translation>Eroare necunoscută</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="67"/>
        <source>D-Bus is not running</source>
        <translation>D-Bus nu rulează</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="144"/>
        <source>No keychain service available</source>
        <translatorcomment>Nu există niciun serviciu de chei disponibil</translatorcomment>
        <translation>Kein Schlüsselbund-Dienst verfügbar</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="146"/>
        <source>Could not open wallet: %1; %2</source>
        <translation>Nu se poate deschide portofelul: %1; %2</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="192"/>
        <source>Access to keychain denied</source>
        <translation>Acces interzis la serviciul de chei</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="213"/>
        <source>Could not determine data type: %1; %2</source>
        <translation>Nu se poate stabili tipul de date: %1: %2</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="231"/>
        <source>Unsupported entry type &apos;Map&apos;</source>
        <translation>Tip de înregistrare nesuportat &apos;Map&apos;</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="234"/>
        <source>Unknown kwallet entry type &apos;%1&apos;</source>
        <translation>Tip de înregistrare kwallet necunoscut &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="249"/>
        <source>Could not read password: %1; %2</source>
        <translation>Nu se poate citi parola: %1; %2</translation>
    </message>
    <message>
        <location filename="../keychain_mac.cpp" line="76"/>
        <source>Password not found</source>
        <translation>Parola nu a fost găsită</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="222"/>
        <location filename="../keychain_win.cpp" line="27"/>
        <source>Entry not found</source>
        <translation>Înregistrarea nu a fost găsită</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="44"/>
        <source>Could not decrypt data</source>
        <translation>Nu se poate decripta data</translation>
    </message>
</context>
<context>
    <name>QKeychain::WritePasswordJobPrivate</name>
    <message>
        <location filename="../keychain_unix.cpp" line="270"/>
        <location filename="../keychain_unix.cpp" line="278"/>
        <source>Unknown error</source>
        <translation>Eroare necunoscută</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="293"/>
        <source>D-Bus is not running</source>
        <translation>D-Bus nu rulează</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="334"/>
        <location filename="../keychain_unix.cpp" line="410"/>
        <source>Could not open wallet: %1; %2</source>
        <translation>Nu se poate deschide portofelul: %1; %2</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="388"/>
        <source>Access to keychain denied</source>
        <translation>Acces interzis la serviciul de chei</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="64"/>
        <source>Could not delete encrypted data from settings: access error</source>
        <translation>Nu se pot șterge datele criptate din setări: eroare de acces</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="65"/>
        <source>Could not delete encrypted data from settings: format error</source>
        <translation>Nu se pot șterge datele criptate din setări: eroare de format</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="85"/>
        <source>Encryption failed</source>
        <translation>Criptarea a eșuat</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="100"/>
        <source>Could not store encrypted data in settings: access error</source>
        <translation>Nu se pot stoca datele criptate în setări: eroare de acces</translation>
    </message>
    <message>
        <location filename="../keychain_win.cpp" line="101"/>
        <source>Could not store encrypted data in settings: format error</source>
        <translation>Nu se pot stoca datele criptate în setări: eroare de format</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../keychain_unix.cpp" line="89"/>
        <source>Access to keychain denied</source>
        <translation>Acces interzis la serviciul de chei</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="91"/>
        <source>No keyring daemon</source>
        <translation>Niciun demon pentru inelul de chei</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="93"/>
        <source>Already unlocked</source>
        <translation>Deja deblocat</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="95"/>
        <source>No such keyring</source>
        <translation>Nu există astfel de inel de chei</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="97"/>
        <source>Bad arguments</source>
        <translation>Argumente greșite</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="99"/>
        <source>I/O error</source>
        <translation>Eroare de I/E</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="101"/>
        <source>Cancelled</source>
        <translation>Anulat</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="103"/>
        <source>Keyring already exists</source>
        <translation>Inelul de chei deja există</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="105"/>
        <source>No match</source>
        <translation>Nicio potrivire</translation>
    </message>
    <message>
        <location filename="../keychain_unix.cpp" line="110"/>
        <source>Unknown error</source>
        <translation>Eroare necunoscută</translation>
    </message>
    <message>
        <location filename="../keychain_mac.cpp" line="31"/>
        <location filename="../keychain_mac.cpp" line="33"/>
        <source>%1 (OSStatus %2)</source>
        <translation>%1 (OSStatus %2)</translation>
    </message>
</context>
</TS>
